@@ -38,6 +38,9 @@ class Task(BaseModel):
     metadata: Optional[Dict[str, Any]] = Field(
         default_factory=dict, description="Additional task metadata"
     )
+    output_json_schema: Optional[Dict[str, Any]] = Field(
+        None, description="JSON schema for expected output format"
+    )
 
     @validator("key")
     def validate_key_format(cls, v):
@@ -206,17 +209,60 @@ class Task(BaseModel):
             )
             self.verifier = verifier
 
-    async def make_env(self, region: Optional[str] = None):
+    async def make_env(
+        self,
+        region: Optional[str] = None,
+        image_type: Optional[str] = None,
+        ttl_seconds: Optional[int] = None,
+    ):
         """Create an environment instance for this task's environment.
 
-        Uses the task's env_id (and version if present) to create the env.
+        Alias for make() method. Uses the task's env_id (and version if present) to create the env.
+        """
+        return await self.make(
+            region=region, image_type=image_type, ttl_seconds=ttl_seconds
+        )
+
+    async def make(
+        self,
+        region: Optional[str] = None,
+        image_type: Optional[str] = None,
+        ttl_seconds: Optional[int] = None,
+    ):
+        """Create an environment instance with task's configuration.
+
+        Auto-populates environment creation with:
+        - env_key (env_id + version)
+        - data_key (data_id + data_version, if present)
+        - env_variables (if present)
+
+        Args:
+            region: Optional AWS region for the environment
+            image_type: Optional image type for the environment
+            ttl_seconds: Optional TTL in seconds for the instance
+
+        Returns:
+            Environment instance configured for this task
+
+        Example:
+            task = fleet.Task(key="my-task", prompt="...", env_id="my-env",
+                            data_id="my-data", data_version="v1.0")
+            env = await task.make(region="us-west-2")
         """
         if not self.env_id:
             raise ValueError("Task has no env_id defined")
-        # Deferred import to avoid circular dependencies
-        from .client import AsyncFleet
 
-        return await AsyncFleet().make(env_key=self.env_key, region=region)
+        # Deferred import to avoid circular dependencies
+        from fleet.env import make_async
+
+        return await make_async(
+            env_key=self.env_key,
+            data_key=self.data_key,
+            region=region,
+            env_variables=self.env_variables if self.env_variables else None,
+            image_type=image_type,
+            ttl_seconds=ttl_seconds,
+        )
 
 
 def verifier_from_string(
@@ -235,10 +281,18 @@ def verifier_from_string(
     """
     try:
         import inspect
+        import re
         from .verifiers.verifier import AsyncVerifierFunction
         from fleet.verifiers.code import TASK_SUCCESSFUL_SCORE, TASK_FAILED_SCORE
         from fleet.verifiers.db import IgnoreConfig
 
+        # Strip @verifier decorator if present to avoid double-wrapping
+        # Remove lines like: @verifier(key="...")
+        cleaned_code = re.sub(r"@verifier\([^)]*\)\s*\n", "", verifier_func)
+        # Also remove the verifier import if present
+        cleaned_code = re.sub(r"from fleet import.*verifier.*\n", "", cleaned_code)
+        cleaned_code = re.sub(r"import.*verifier.*\n", "", cleaned_code)
+
         # Create a local namespace for executing the code
         local_namespace = {
             "TASK_SUCCESSFUL_SCORE": TASK_SUCCESSFUL_SCORE,
@@ -247,13 +301,15 @@ def verifier_from_string(
             "Environment": object,  # Add Environment type if needed
         }
 
-        # Execute the verifier code in the namespace
-        exec(verifier_func, globals(), local_namespace)
+        # Execute the cleaned verifier code in the namespace
+        exec(cleaned_code, globals(), local_namespace)
 
-        # Find the function that was defined
+        # Find the function that was defined (not imported)
+        # Functions defined via exec have co_filename == '<string>'
+        # Imported functions have their actual module file path
         func_obj = None
         for name, obj in local_namespace.items():
-            if inspect.isfunction(obj):
+            if inspect.isfunction(obj) and obj.__code__.co_filename == "<string>":
                 func_obj = obj
                 break
 
@@ -293,6 +349,7 @@ async def load_tasks(
     version: Optional[str] = None,
     team_id: Optional[str] = None,
     project_key: Optional[str] = None,
+    task_project_key: Optional[str] = None,
     data_id: Optional[str] = None,
     data_version: Optional[str] = None,
 ) -> List[Task]:
@@ -304,6 +361,7 @@ async def load_tasks(
         version: Optional version to filter tasks by
         team_id: Optional team_id to filter by (admin only)
         project_key: Optional project key to filter tasks by
+        task_project_key: Optional task project key to filter tasks by
         data_id: Optional data identifier to filter tasks by
         data_version: Optional data version to filter tasks by
 
@@ -323,13 +381,14 @@ async def load_tasks(
         version=version,
         team_id=team_id,
         project_key=project_key,
+        task_project_key=task_project_key,
         data_id=data_id,
         data_version=data_version,
     )
 
 
 async def update_task(
-    task_key: str, prompt: Optional[str] = None, verifier_code: Optional[str] = None
+    task_key: str, prompt: Optional[str] = None, verifier_code: Optional[str] = None, metadata: Optional[Dict[str, Any]] = None
 ):
     """Convenience function to update an existing task.
 
@@ -337,6 +396,7 @@ async def update_task(
         task_key: The key of the task to update
         prompt: New prompt text for the task (optional)
         verifier_code: Python code for task verification (optional)
+        metadata: Additional metadata for the task (optional)
 
     Returns:
         TaskResponse containing the updated task details
@@ -344,12 +404,39 @@ async def update_task(
     Examples:
         response = await fleet.update_task("my-task", prompt="New prompt text")
         response = await fleet.update_task("my-task", verifier_code="def verify(env): return True")
+        response = await fleet.update_task("my-task", metadata={"seed": 42, "story": "Updated story"})
     """
     from .global_client import get_client
 
     client = get_client()
     return await client.update_task(
-        task_key=task_key, prompt=prompt, verifier_code=verifier_code
+        task_key=task_key, prompt=prompt, verifier_code=verifier_code, metadata=metadata
+    )
+
+
+async def get_task(
+    task_key: str, version_id: Optional[str] = None, team_id: Optional[str] = None
+):
+    """Convenience function to get a task by key and optional version.
+
+    Args:
+        task_key: The key of the task to retrieve
+        version_id: Optional version ID to filter by
+        team_id: Optional team_id to filter by (admin only)
+
+    Returns:
+        TaskResponse containing the task details
+
+    Examples:
+        response = await fleet.get_task("my-task")
+        response = await fleet.get_task("my-task", version_id="v1")
+        response = await fleet.get_task("my-task", team_id="team-123")
+    """
+    from .global_client import get_client
+
+    client = get_client()
+    return await client.get_task(
+        task_key=task_key, version_id=version_id, team_id=team_id
     )
 
 
